@@ -3531,7 +3531,9 @@ static PurplePluginProtocolInfo prpl_info = {
 	NULL,						/* get_media_caps */
 	NULL,						/* get_moods */
 	NULL,						/* set_public_alias */
-	NULL						/* get_public_alias */
+	NULL,						/* get_public_alias */
+	NULL,						/* add_buddy_with_invite */
+	NULL						/* add_buddies_with_invite */
 };
 
 static PurplePluginInfo info = {
